@@ -42,7 +42,7 @@ class AKONADI_SEARCH_XAPIAN_EXPORT XapianSearchStore : public SearchStore
     Q_OBJECT
 public:
     explicit XapianSearchStore(QObject *parent = nullptr);
-    virtual ~XapianSearchStore();
+    ~XapianSearchStore() override;
 
     int exec(const Query &query) override;
     void close(int queryId) override;
@@ -127,7 +127,7 @@ private:
 
     QString m_dbPath;
 
-    Xapian::Database *m_db;
+    Xapian::Database *m_db = nullptr;
 };
 
 }
